@@ -88,4 +88,9 @@ utils::globalVariables(c("%>%",
                          "Immgen.GSE122108.412",
                          "Immgen.GSE109125.205",
                          "yend",
+                         "gg_color_hue",
+                         "hcl",
+                         "V",
+                         "CellIds",
+                         "V<-",
                          "annotate"))
